<?php

namespace App\Http\Controllers;

use App\Http\Requests\StoreUpdateTituloRequest;
use App\Models\Agendamento;
use App\Models\DocumentoPessoa;
use App\Models\Lote;
use App\Models\LoteTramite;
use App\Models\Pessoa;
use App\Models\PessoaLote;
use App\Models\Titulo;
use App\Models\Tramite;
use Illuminate\Http\Request;

class TituloController extends Controller
{
    protected $request;
    //Injeção de dependência
    public function __construct(Request $request)
    {
        $this->request = $request;
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $documentoPessoa = DocumentoPessoa::where('cpf', $this->request->cpf)->with('pessoa')->first();
        if ($documentoPessoa) {
            $pessoas = Pessoa::where('id', $documentoPessoa->pessoa_id)->get();
            foreach ($pessoas as $pessoa) {
                $pessoasLote = PessoaLote::where('pessoa_id', $documentoPessoa->pessoa_id)->with('lote')->get();
                foreach ($pessoasLote as $pessoaLote) {
                    $lotes = Lote::where('id', $pessoaLote->lote_id)
                        ->with('lotesTramites', 'municipio')
                        ->get();
                    foreach ($lotes as $lote) {
                        $loteTramite = LoteTramite::where('lote_id', $pessoaLote->lote_id)->max('id');
                        $lotesTramites = LoteTramite::where('id', $loteTramite)->get();
                        foreach ($lotesTramites as $lotTramite) {
                            $tramites = Tramite::where('id', $lotTramite->tramite_id)->get();
                            foreach ($tramites as $tramite) {
                                if ($tramite->nome === "ARQUIVO PRONTO PARA ENTREGA") {
                                    $titulos = Titulo::where('lote_id', $lote->id)->where('flag_cancelamento', '<>', 'S')->get();
                                    foreach ($titulos as $titulo) {
                                        $agendamentos = Agendamento::get()->last();
                                        if ($agendamentos) {
                                            return view(
                                                'admin.pages.titulos.index',
                                                [
                                                    'titulos' => $titulos,
                                                    'lotes' => $lotes,
                                                    'documentoPessoa' => $documentoPessoa,
                                                    'loteTramite' => $loteTramite,
                                                    'tramite' => $tramite,
                                                    'agendamentos' => $agendamentos,
                                                ]
                                            );
                                        }
                                    }
                                } else {
                                    return view('cpfValidoSemTitulo')->with(['cpf' => $this->request->cpf]);
                                }
                            }

                        }
                    }
                }
            }
        } else {
            return view('cpfInvalido')->with(['cpf' => $this->request->cpf]);
        }
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.pages.titulos.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  App\Http\Requests\StoreUpdateTituloRequest  $request
     * @return \Illuminate\Http\Response
     */
    // public function store(StoreUpdateTituloRequest $request)
    // {
    //     $data = $request->all();
    //     $this->repository->create($data);
    //     return redirect()->route('titulos.index');

    // }

    //guardar data
    public function store(Request $request)
    {

        return $request->name;
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if (!$lotes = Lote::find($id)) {
            return redirect()->back();
        } else {
            return view('admin.pages.titulos.show', [
                'lotes' => $lotes,
            ]);
        }

        if (!$titulos = Titulo::where('lote_id', $id)->get()) {
            return redirect()->back();
        } else {
            return view('admin.pages.titulos.show', [
                'titulos' => $titulos,
            ]);
        }

        if (!$agendamentos = Agendamento::get()->last()) {
            return redirect()->back();
        } else {
            return view('admin.pages.titulos.show', [
                'agendamentos' => $agendamentos,
            ]);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if (!$titulo = $this->repository->find($id)) {
            return redirect()->back();
        }

        //dd($titulo);
        // return view('admin.pages.titulos.edit', [
        //     'titulos' => $titulo
        // ]);
        return view('admin.pages.titulos.edit', compact('titulo'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(StoreUpdateTituloRequest $request, $id)
    {
        if (!$titulo = $this->repository->find($id)) {
            return redirect()->back();
        }

        $titulo->update($request->all());
        return redirect()->route('titulos.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if (!$titulo = $this->repository->find($id)) {
            return redirect()->back();
        }

        $titulo->delete();

        return redirect()->route('titulos.index');
    }

    public function search(Request $request)
    {
        $filters = $request->except('_token');

        $titulos = $this->repository->search($request->filter);

        return view('admin.pages.titulos.index', [
            'titulos' => $titulos,
            'filters' => $filters,
        ]);

    }
}
